==> weibulltools_2.0.0.tar.gz: weibulltools/tests/testthat/_snaps/delay_distributions.md <==
# dist_delay remains stable

          sc 
    28.91667 

---

     [1]  NA  24  55   5  NA  NA  22  NA  33  21  29  NA 102  NA  NA  14  NA  30  NA
    [20]   6   6  NA  NA

# mcs_delay remains stable by defining the seed

    Reliability data with characteristic 'time':
    # A tibble: 23 x 7
       date_1.1   date_1.2   date_2.1   date_2.2    time status id   
       <chr>      <chr>      <chr>      <chr>      <dbl>  <dbl> <chr>
     1 2014-07-28 <NA>       <NA>       <NA>        969.      0 ID1  
     2 2014-02-17 2014-09-15 2014-03-29 2014-10-09 1000       1 ID2  
     3 2014-07-14 2015-07-04 2014-12-06 2015-08-28 1000       1 ID3  
     4 2014-06-26 2015-04-10 2014-09-09 2015-04-15 1000       1 ID4  
     5 2014-03-10 <NA>       <NA>       <NA>        940.      0 ID5  
     6 2014-05-14 <NA>       <NA>       <NA>        891.      0 ID6  
     7 2014-05-06 2015-04-24 2014-06-16 2015-05-16 1000       1 ID7  
     8 2014-03-07 <NA>       <NA>       <NA>        944.      0 ID8  
     9 2014-03-09 2015-04-25 2014-05-23 2015-05-28 1000       1 ID9  
    10 2014-04-13 2015-04-24 2014-05-09 2015-05-15 1000       1 ID10 
    # ... with 13 more rows

---

    # A tibble: 23 x 2
       sim_delay.1 sim_delay.2
             <dbl>       <dbl>
     1        21.2      10.2  
     2         0         0    
     3         0         0    
     4         0         0    
     5        59.6       0.263
     6        62.5      46.6  
     7         0         0    
     8        32.2      23.5  
     9         0         0    
    10         0         0    
    # ... with 13 more rows

# dist_delay_register remains stable

          loc        sc 
    3.8164980 0.6578434 

# dist_delay_report remains stable

         loc       sc 
    3.348741 1.616017 

# mcs_delay_register remains stable by defining the seed

    $time
     [1]  978.7677 1000.0000 1000.0000 1000.0000  945.8695  909.9679 1000.0000
     [8]  989.6427 1000.0000 1000.0000 1000.0000  940.4371 1000.0000  937.4771
    [15]  968.3682 1000.0000  967.8027 1000.0000  968.1624 1000.0000 1000.0000
    [22]  974.0703  966.3619
    
    $x_sim
     [1] 21.23230 54.13054 90.03206 10.35731 59.56287 62.52287 31.63180 32.19732
     [9] 31.83762 25.92969 33.63812
    
    $coefficients
          loc        sc 
    3.8164980 0.6304333 
    

# mcs_delay_report remains stable by defining the seed

    $time
     [1]  992.6815 1000.0000 1000.0000 1000.0000  974.5569  949.9098 1000.0000
     [8]  997.1858 1000.0000 1000.0000 1000.0000  971.1020 1000.0000  969.1744
    [15]  987.5570 1000.0000  987.2599 1000.0000  987.4491 1000.0000 1000.0000
    [22]  990.4503  986.4953
    
    $x_sim
     [1]  7.318486 25.443087 50.090217  2.814177 28.898009 30.825629 12.443008
     [8] 12.740067 12.550923  9.549676 13.504690
    
    $coefficients
         loc       sc 
    3.003578 0.839370 
    

# mcs_delays remains stable by defining the seed

    $time
     [1]  992.6815 1000.0000 1000.0000 1000.0000  974.5569  949.9098 1000.0000
     [8]  997.1858 1000.0000 1000.0000 1000.0000  971.1020 1000.0000  969.1744
    [15]  987.5570 1000.0000  987.2599 1000.0000  987.4491 1000.0000 1000.0000
    [22]  990.4503  986.4953
    
    $x_sim_regist
    numeric(0)
    
    $x_sim_report
     [1]  7.318486 25.443087 50.090217  2.814177 28.898009 30.825629 12.443008
     [8] 12.740067 12.550923  9.549676 13.504690
    
    $coefficients_regist
          loc        sc 
    3.7870654 0.6029592 
    
    $coefficients_report
         loc       sc 
    3.003578 0.839370

==> weibulltools_2.1.0.tar.gz: weibulltools/tests/testthat/_snaps/delay_distributions.md <==
# dist_delay remains stable

          sc 
    28.91667 

---

     [1]  NA  24  55   5  NA  NA  22  NA  33  21  29  NA 102  NA  NA  14  NA  30  NA
    [20]   6   6  NA  NA

# mcs_delay remains stable by defining the seed

    Reliability Data with characteristic x: 'time':
    # A tibble: 23 x 7
       date_1.1   date_1.2   date_2.1   date_2.2       x status id   
       <chr>      <chr>      <chr>      <chr>      <dbl>  <dbl> <chr>
     1 2014-07-28 <NA>       <NA>       <NA>        969.      0 ID1  
     2 2014-02-17 2014-09-15 2014-03-29 2014-10-09 1000       1 ID2  
     3 2014-07-14 2015-07-04 2014-12-06 2015-08-28 1000       1 ID3  
     4 2014-06-26 2015-04-10 2014-09-09 2015-04-15 1000       1 ID4  
     5 2014-03-10 <NA>       <NA>       <NA>        940.      0 ID5  
     6 2014-05-14 <NA>       <NA>       <NA>        891.      0 ID6  
     7 2014-05-06 2015-04-24 2014-06-16 2015-05-16 1000       1 ID7  
     8 2014-03-07 <NA>       <NA>       <NA>        944.      0 ID8  
     9 2014-03-09 2015-04-25 2014-05-23 2015-05-28 1000       1 ID9  
    10 2014-04-13 2015-04-24 2014-05-09 2015-05-15 1000       1 ID10 
    # i 13 more rows

---

    # A tibble: 23 x 2
       sim_delay_1 sim_delay_2
             <dbl>       <dbl>
     1        21.2      10.2  
     2         0         0    
     3         0         0    
     4         0         0    
     5        59.6       0.263
     6        62.5      46.6  
     7         0         0    
     8        32.2      23.5  
     9         0         0    
    10         0         0    
    # i 13 more rows

# dist_delay_register remains stable

          loc        sc 
    3.8164980 0.6578434 

# dist_delay_report remains stable

         loc       sc 
    3.348741 1.616017 

# mcs_delay_register remains stable by defining the seed

    $time
     [1]  978.7677 1000.0000 1000.0000 1000.0000  945.8695  909.9679 1000.0000
     [8]  989.6427 1000.0000 1000.0000 1000.0000  940.4371 1000.0000  937.4771
    [15]  968.3682 1000.0000  967.8027 1000.0000  968.1624 1000.0000 1000.0000
    [22]  974.0703  966.3619
    
    $x_sim
     [1] 21.23230 54.13054 90.03206 10.35731 59.56287 62.52287 31.63180 32.19732
     [9] 31.83762 25.92969 33.63812
    
    $coefficients
          loc        sc 
    3.8164980 0.6304333 
    

# mcs_delay_report remains stable by defining the seed

    $time
     [1]  992.6815 1000.0000 1000.0000 1000.0000  974.5569  949.9098 1000.0000
     [8]  997.1858 1000.0000 1000.0000 1000.0000  971.1020 1000.0000  969.1744
    [15]  987.5570 1000.0000  987.2599 1000.0000  987.4491 1000.0000 1000.0000
    [22]  990.4503  986.4953
    
    $x_sim
     [1]  7.318486 25.443087 50.090217  2.814177 28.898009 30.825629 12.443008
     [8] 12.740067 12.550923  9.549676 13.504690
    
    $coefficients
         loc       sc 
    3.003578 0.839370 
    

# mcs_delays remains stable by defining the seed

    $time
     [1]  992.6815 1000.0000 1000.0000 1000.0000  974.5569  949.9098 1000.0000
     [8]  997.1858 1000.0000 1000.0000 1000.0000  971.1020 1000.0000  969.1744
    [15]  987.5570 1000.0000  987.2599 1000.0000  987.4491 1000.0000 1000.0000
    [22]  990.4503  986.4953
    
    $x_sim_regist
    numeric(0)
    
    $x_sim_report
     [1]  7.318486 25.443087 50.090217  2.814177 28.898009 30.825629 12.443008
     [8] 12.740067 12.550923  9.549676 13.504690
    
    $coefficients_regist
          loc        sc 
    3.7870654 0.6029592 
    
    $coefficients_report
         loc       sc 
    3.003578 0.839370
